@@ -1,8 +1,8 @@
 /*                                                                -*- C -*-
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2017 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -18,7 +18,7 @@
 
 /* $Id$ */
 
-#define CONFIGURE_COMMAND " './configure'  '--prefix=/usr' '--exec_prefix=/usr' '--bindir=/usr/bin' '--sbindir=/usr/sbin' '--libexecdir=/usr/libexec' '--datadir=/usr/share' '--sysconfdir=/etc' '--sharedstatedir=/usr/share' '--localstatedir=/var' '--libdir=/usr/lib' '--infodir=/usr/share/info' '--includedir=/usr/include' '--mandir=/usr/share/man' '--with-zlib' '--with-openssl' '--enable-ftp' '--with-gd' '--with-jpeg-dir=/usr' '--with-freetype-dir=/usr/include/freetype2' '--enable-gd-native-ttf' '--with-pgsql' '--with-gettext' '--with-apxs2=/usr/bin/apxs' '--with-pear' '--with-mcrypt' '--enable-zip' '--with-bz2' '--enable-mbstring' '--with-mysql' '--with-mysqli' '--with-pdo-mysql' '--with-pdo-pgsql' '--with-pdo-sqlite' '--with-mysql-sock=/var/run/mysql/mysql.sock' '--enable-bcmath' '--enable-sockets' '--with-imap=/usr' '--with-imap-ssl=/usr' 'CC=cc' 'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= 'CPP=cc '-E'' 'CXX=g++'"
+#define CONFIGURE_COMMAND " './configure'  '--prefix=/usr' '--exec_prefix=/usr' '--bindir=/usr/bin' '--sbindir=/usr/sbin' '--libexecdir=/usr/libexec' '--datadir=/usr/share' '--sysconfdir=/etc' '--sharedstatedir=/usr/share' '--localstatedir=/var' '--libdir=/usr/lib' '--infodir=/usr/share/info' '--includedir=/usr/include' '--mandir=/usr/share/man' '--with-zlib' '--with-openssl' '--enable-ftp' '--with-gd' '--with-jpeg-dir=/usr' '--with-freetype-dir=/usr/include/freetype2' '--enable-gd-native-ttf' '--with-pgsql' '--with-gettext' '--with-apxs2=/usr/bin/apxs' '--with-pear' '--with-mcrypt' '--enable-zip' '--with-bz2' '--enable-mbstring' '--with-mysql' '--with-mysqli' '--with-pdo-mysql' '--with-pdo-pgsql' '--with-pdo-sqlite' '--with-mysql-sock=/var/run/mysql/mysql.sock' '--enable-bcmath' '--enable-sockets' '--with-imap=/usr' '--with-imap-ssl=/usr' 'CFLAGS=' 'LDFLAGS=' 'CPP=cc -E'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -37,16 +37,16 @@
 #define PHP_IFX_INCLUDE		""
 #define PHP_IFX_LFLAGS		""
 #define PHP_IFX_LIBS		""
-#define PHP_INSTALL_IT		"$(mkinstalldirs) '$(INSTALL_ROOT)/usr/libexec/apache2' &&                 $(mkinstalldirs) '$(INSTALL_ROOT)/etc/apache2' &&                  /usr/bin/apxs -S LIBEXECDIR='$(INSTALL_ROOT)/usr/libexec/apache2'                        -S SYSCONFDIR='$(INSTALL_ROOT)/etc/apache2'                        -i -a -n php5 libphp5.la"
+#define PHP_INSTALL_IT		"$(mkinstalldirs) '$(INSTALL_ROOT)/usr/libexec/apache2' &&                 $(mkinstalldirs) '$(INSTALL_ROOT)/etc/apache2' &&                  /usr/bin/apxs -S LIBEXECDIR='$(INSTALL_ROOT)/usr/libexec/apache2'                        -S SYSCONFDIR='$(INSTALL_ROOT)/etc/apache2'                        -i -a -n php7 libphp7.la"
 #define PHP_IODBC_INCLUDE	""
 #define PHP_IODBC_LFLAGS	""
 #define PHP_IODBC_LIBS		""
 #define PHP_MSQL_INCLUDE	""
 #define PHP_MSQL_LFLAGS		""
 #define PHP_MSQL_LIBS		""
-#define PHP_MYSQL_INCLUDE	""
-#define PHP_MYSQL_LIBS		""
-#define PHP_MYSQL_TYPE		""
+#define PHP_MYSQL_INCLUDE	"@MYSQL_INCLUDE@"
+#define PHP_MYSQL_LIBS		"@MYSQL_LIBS@"
+#define PHP_MYSQL_TYPE		"@MYSQL_MODULE_TYPE@"
 #define PHP_ODBC_INCLUDE	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
@@ -77,7 +77,7 @@
 #define PHP_BIRDSTEP_LIBS        ""
 #define PEAR_INSTALLDIR         "/usr/lib/php"
 #define PHP_INCLUDE_PATH	".:/usr/lib/php"
-#define PHP_EXTENSION_DIR       "/usr/lib/extensions/no-debug-non-zts-20131226"
+#define PHP_EXTENSION_DIR       "/usr/lib/extensions/no-debug-non-zts-20160303"
 #define PHP_PREFIX              "/usr"
 #define PHP_BINDIR              "/usr/bin"
 #define PHP_SBINDIR             "/usr/sbin"
